biom.table.Table.max — biom-format.org

# biom-format.org

## biom.table.Table.max

`Table.` `max`(axis='sample')

  Get the maximum nonzero value over an axis

  Parameters: | axis : {‘sample’, ‘observation’, ‘whole’}, optional Defaults to “sample”. The axis over which to calculate maxima.
  Returns: | scalar of self.dtype or np.array of self.dtype
  Raises: | UnknownAxisError If provided an unrecognized axis.

  Examples

      >>> from biom import example_table
      >>> print example_table.max(axis='observation')
      [ 2.  5.]